@@ -38,8 +38,6 @@ pub mod device_calibration;
 pub use self::device_calibration::DeviceCalibration;
 pub mod device_calibration_request;
 pub use self::device_calibration_request::DeviceCalibrationRequest;
-pub mod device_config;
-pub use self::device_config::DeviceConfig;
 pub mod device_info;
 pub use self::device_info::DeviceInfo;
 pub mod device_info_request;
@@ -132,8 +130,6 @@ pub mod paginated_cloudiot_device_list;
 pub use self::paginated_cloudiot_device_list::PaginatedCloudiotDeviceList;
 pub mod paginated_device_calibration_list;
 pub use self::paginated_device_calibration_list::PaginatedDeviceCalibrationList;
-pub mod paginated_device_config_list;
-pub use self::paginated_device_config_list::PaginatedDeviceConfigList;
 pub mod paginated_device_info_list;
 pub use self::paginated_device_info_list::PaginatedDeviceInfoList;
 pub mod paginated_device_list;
